avro\_to\_python.utils.avro package
===================================

Subpackages
-----------

.. toctree::

   avro_to_python.utils.avro.files
   avro_to_python.utils.avro.types

Submodules
----------

avro\_to\_python.utils.avro.helpers module
------------------------------------------

.. automodule:: avro_to_python.utils.avro.helpers
   :members:
   :undoc-members:
   :show-inheritance:

avro\_to\_python.utils.avro.primitive\_types module
---------------------------------------------------

.. automodule:: avro_to_python.utils.avro.primitive_types
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: avro_to_python.utils.avro
   :members:
   :undoc-members:
   :show-inheritance:
